/*
 * Copyright (C) 2003-2004 Red Hat Inc. All Rights Reserved.
 *
 * The contents of this file are subject to the CCM Public
 * License (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the
 * License at http://www.redhat.com/licenses/ccmpl.html.
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language
 * governing rights and limitations under the License.
 *
 */
package com.arsdigita.search.lucene;


import org.apache.lucene.search.Filter;
import org.apache.lucene.index.IndexReader;

import java.util.BitSet;
import java.io.IOException;

import org.apache.log4j.Logger;


/**
 * A filter whose bitset is the logical
 * NOT of the bitset generated by the
 * wrapped filter.
 */
public class NegationFilter extends Filter {

    private static final Logger s_log = 
        Logger.getLogger(NegationFilter.class);
    
    private Filter m_filter;
    
    public NegationFilter(Filter filter) {
        m_filter = filter;
    }
    
    /**
     * @return bitset for the negation of the wrapped filter
     */
    public BitSet bits(IndexReader reader)
        throws IOException {
        
        BitSet bits = new BitSet(reader.maxDoc());
        if (s_log.isDebugEnabled()) {
            s_log.debug("Adding filter " + m_filter.getClass());
        }
        bits.xor(m_filter.bits(reader));
        return bits;
    }
}
